@@ -1,11 +1,13 @@
 import * as React from "react";
-import Memory from "./Memory.jsx";
+import Memory from "./Memory";
 
-type Props = {
+type OwnProps = {
   addr: string;
   style?: React.CSSProperties;
 };
 
+type Props = OwnProps & typeof MemoryLink.defaultProps;
+
 class MemoryLink extends React.Component<Props> {
   render() {
     // turn 0x00000000000000 into 0x0
